@@ -1,5 +1,5 @@
 package Form::Factory::Control::Checkbox;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 use Moose;
 
 with qw(
@@ -14,7 +14,7 @@ Form::Factory::Control::Checkbox - the checkbox control
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -31,14 +31,16 @@ version 0.014
 
 This represents a toggle button, typically displayed as a checkbox. This control implements L<Form::Factory::Control>, L<Form::Factory::Control::Role::BooleanValue>, L<Form::Factory::Control::Role::Labeled>, L<Form::Factory::Control::Role::ScalarValue>.
 
-=head2 stashable_keys
-
-The L</is_true> attribute is stashed.
-
 =cut
 
-has '+stashable_keys' => (
-    default   => sub { [ qw( is_true ) ] },
+has '+value' => (
+    isa       => 'Str',
+);
+
+has '+default_value' => (
+    isa       => 'Str',
+    lazy      => 1,
+    default   => sub { shift->false_value },
 );
 
 =head1 METHODS
@@ -51,42 +53,6 @@ Boolean values default to C<Bool>.
 
 use constant default_isa => 'Str';
 
-=head2 current_value
-
-Returns the L</true_value> if L</is_true> is true. Returns L</false_value> otherwise.
-
-If the control is neither true nor false, it returns C<undef>.
-
-=cut
-
-sub current_value { 
-    my $self = shift;
-
-    if (@_) {
-        $self->value(@_);
-    }
-
-    # blow off these warnings rather than test for them
-    no warnings 'uninitialized';
-
-    return $self->true_value  if $self->true_value  eq $self->value;
-    return $self->false_value if $self->false_value eq $self->value;
-    return;
-}
-
-=head2 has_current_value
-
-If the value is true or false, it has a current value. Otherwise, it does not.
-
-=cut
-
-sub has_current_value {
-    my $self = shift;
-
-    return ($self->true_value  eq $self->value
-         || $self->false_value eq $self->value);
-}
-
 =head1 AUTHOR
 
 Andrew Sterling Hanenkamp C<< <hanenkamp@cpan.org> >>
