@@ -1,5 +1,5 @@
 package Form::Factory::Control::FullText;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 use Moose;
 
 with qw(
@@ -15,7 +15,7 @@ Form::Factory::Control::FullText - The full_text control
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -32,56 +32,32 @@ version 0.014
 
 This is a multi-line text control.
 
-=head1 ATTRIBUTES
-
-=head2 default_value
-
-The default value of the control.
-
 =cut
 
-has default_value => (
-    is        => 'rw',
+has '+value' => (
     isa       => 'Str',
-    predicate => 'has_default_value',
 );
 
-=head2 stashable_keys
-
-The L</value> is stashed.
-
-=cut
-
-has '+stashable_keys' => (
-    default   => sub { [ qw( value ) ] },
+has '+default_value' => (
+    isa       => 'Str',
+    default   => '',
 );
 
 =head1 METHODS
 
-=head2 current_value
-
-This use the L</value> if available. It falls back to L</default_value> otherwise. It returns an empty string if neither are set.
-
-=cut
-
-sub current_value {
-    my $self = shift;
-    $self->value(shift) if @_;
-    return $self->has_value         ? $self->value
-         : $self->has_default_value ? $self->default_value
-         :                            '';
-}
-
 =head2 has_current_value
 
-We have a useful current value when it is defined and the length of the string is greater than zero.
+We have a current value if it is defined and has a non-zero string length.
 
 =cut
 
-sub has_current_value {
+around has_current_value => sub {
+    my $next = shift;
     my $self = shift;
-    return length($self->current_value) > 0;
-}
+
+    return ($self->has_value || $self->has_default_value)
+        && length($self->current_value) > 0;
+};
 
 =head1 AUTHOR
 
