@@ -1,5 +1,5 @@
 package Form::Factory::Control::Password;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 use Moose;
 
 with qw( 
@@ -14,7 +14,7 @@ Form::Factory::Control::Password - the password control
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -26,31 +26,32 @@ head1 DESCRIPTION
 
 This is a password control. It is similar to a text control, but does not stash anything and has no default value.
 
-=head1 METHODS
-
-=head2 current_value
-
-This returns L</value> if set or an empty string.
-
 =cut
 
-sub current_value {
-    my $self = shift;
-    $self->value(shift) if @_;
-    return $self->has_value ? $self->value
-         :                    '';
-}
+has '+value' => (
+    isa       => 'Str',
+);
+
+has '+default_value' => (
+    isa       => 'Str',
+    default   => '',
+);
+
+=head1 METHODS
 
 =head2 has_current_value
 
-We have a useful current value when it is defined and the length of the string is greater than zero.
+We have a current value if it is defined and has a non-zero string length.
 
 =cut
 
-sub has_current_value {
+around has_current_value => sub {
+    my $next = shift;
     my $self = shift;
-    return length($self->current_value) > 0;
-}
+
+    return ($self->has_value || $self->has_default_value) 
+        && length($self->current_value) > 0;
+};
 
 =head1 AUTHOR
 
