@@ -1,5 +1,5 @@
 package Form::Factory::Interface::HTML;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 use Moose;
 
 with qw( Form::Factory::Interface );
@@ -22,7 +22,7 @@ Form::Factory::Interface::HTML - Simple HTML form interface
 
 =head1 VERSION
 
-version 0.014
+version 0.015
 
 =head1 SYNOPSIS
 
@@ -368,9 +368,6 @@ sub consume_control {
 
     Carp::croak("no request option passed") unless defined $options{request};
 
-    Carp::croak("HTML interface does not know how to consume values for $control")
-        unless $control->does('Form::Factory::Control::Role::Value');
-
     my $widget = $self->new_widget_for_control($control);
     return unless defined $widget;
 
