@@ -1,5 +1,5 @@
 package Form::Factory::Test::Action::Basic;
-our $VERSION = '0.014';
+our $VERSION = '0.015';
 use Test::Able;
 use Test::More;
 use Test::Moose;
@@ -80,7 +80,7 @@ test plan => 6, meta_control_name => sub {
     is_deeply($control->features, {}, 'control features are empty');
 };
 
-test plan => 13, control_name => sub {
+test plan => 12, control_name => sub {
     my $self = shift;
     my $control = $self->action->controls->{name};
 
@@ -91,8 +91,6 @@ test plan => 13, control_name => sub {
     does_ok($control, 'Form::Factory::Control::Role::ScalarValue');
     is($control->name, 'name', 'control is named name');
     is_deeply($control->features, [], 'control features are empty');
-    is_deeply($control->stashable_keys, [ qw( value ) ], 
-        'control value is stashable');
     is($control->has_value, '', 'control has no value');
     is($control->value, undef, 'control value is undef');
     is($control->has_default_value, 1, 'control has a default value');
@@ -113,7 +111,7 @@ test plan => 5, render_control => sub {
     ok($control, 'got a control back');
     isa_ok($control, 'Form::Factory::Control::Button');
     is($control->label, 'Testing', 'button label is Testing');
-    is($control->current_value, '', 'current_value is empty');
+    is($control->current_value, undef, 'current_value is empty');
 };
 
 test plan => 4, consume_control_empty => sub {
@@ -128,7 +126,7 @@ test plan => 4, consume_control_empty => sub {
     ok($control, 'got a control back');
     isa_ok($control, 'Form::Factory::Control::Button');
     is($control->label, 'Testing', 'button label is Testing');
-    is($control->current_value, '', 'current_value is empty');
+    is($control->current_value, undef, 'current_value is empty');
 };
 
 test plan => 4, consume_control_full => sub {
